@@ -425,18 +425,18 @@ class calc_area:
         self.delarea = delarea
         self.unit_area = unit_area
         
-        if isinstance(df, str):
-            data = gpd.read_file(df)
+        if isinstance(self.df, str):
+            data = gpd.read_file(self.df)
             if data.crs == None:
                 data.crs = {'init':'epsg:4326'}
-        elif isinstance(df, gpd.GeoDataFrame):
+        elif isinstance(self.df, gpd.GeoDataFrame):
             data = self.df
             if data.crs == None:
                 data.crs = {'init':'epsg:4326'}
         else:
             raise KeyError(f"{self.df} is errorneous data location, please fix the data location problem")
         
-        if unit_area != None and unit_area == 'meter':
+        if self.unit_area != None and self.unit_area == 'meter':
             data['area_m'] = data.geometry.area*(100000**2)
             ohex = data[data['area_m']>=self.delarea]
             self.geosolution = ohex
